@@ -3,7 +3,7 @@ use 5.008001;
 use strict;
 use warnings;
 
-our $VERSION = "0.01";
+our $VERSION = "0.02";
 
 use Carp ();
 use Guard;  # guard
@@ -57,6 +57,10 @@ sub requested_ok {
     ) or Test::More::diag Test::More::explain [ map { $_->method . ' ' . $_->uri } @Requests ]
 }
 
+sub clear_requests {
+    @Requests = ();
+}
+
 my $app = sub {
     my ($env) = @_;
     my $req = Plack::Request->new($env);
@@ -162,7 +166,7 @@ Test::WWW::Stub - Block and stub specified URL for LWP
 
 Test::WWW::Stub is a helper module to block external http(s) request and stub some specific requests in your test.
 
-Because this modules uses L<LWP::UserAgent::PSGI> internally, you don't have to modify target codes using L<LWP::UserAgent>.
+Because this modules uses L<LWP::Protocol::PSGI> internally, you don't have to modify target codes using L<LWP::UserAgent>.
 
 =head1 METHODS
 
@@ -203,6 +207,14 @@ Returns a Plack::Request object last handled by Test::WWW::Stub.
 
 This method is same as C<[Test::WWW::Stub-E<gt>requests]-E<gt>[-1]>.
 
+=item C<clear_requests>
+
+    Test::WWW::Stub->clear_requests;
+
+Clears request history of Test::WWW::Stub.
+
+C<[Test::WWW::Stub-E<gt>requests]> becomes empty just after this method called.
+
 =item C<unstub>
 
     my $unstub_guard = Test::WWW::Stub->unstub;
